NodeType enum
Node type constants matching the DOM specification.
Values
- unknown → const NodeType
-
const NodeType(-1) - element → const NodeType
-
const NodeType(1) - attribute → const NodeType
-
const NodeType(2) - text → const NodeType
-
const NodeType(3) - cdataSection → const NodeType
-
const NodeType(4) - entityReference → const NodeType
-
const NodeType(5) - entity → const NodeType
-
const NodeType(6) - processingInstruction → const NodeType
-
const NodeType(7) - comment → const NodeType
-
const NodeType(8) - document → const NodeType
-
const NodeType(9) - documentType → const NodeType
-
const NodeType(10) - documentFragment → const NodeType
-
const NodeType(11) - notation → const NodeType
-
const NodeType(12)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited